==> imwiki-0.6.0a.tar.gz: imwiki-0.6.0a/imLib/Page.py <==
# -*- coding: utf8 -*-
import urllib
import os
import shutil
import time

import config
import utils 
from Tag import Tag
from TagManager import TagManager
import Request
import Category
import Repository
import Permission

from WikiException import WikiException
class ExistPage(WikiException): pass 
class EditConflict(WikiException): pass
class NotExistPage(WikiException): pass

def createPage(category, pageName, rawText, tags='', perms=''):
	encPageName = utils.encode(pageName)
	filePath = os.path.join(category.dirPath, encPageName)
	if os.path.isfile(filePath):
		raise ExistPage
	tm = TagManager(tags)
	tags = tm.getTagString()
	if not perms:
		perms = category.perms
	file(filePath, 'wb').write('%s\n%s\n%s' % (perms, tags, rawText))
	page = Page(category, pageName)
	for tag in tm.toSet():
		Tag(tag).append(page)
	return page

class Page:
	def __init__(self, category, pageName):
		self.category = category
		self.pageName = pageName
		self.encPageName = utils.encode(pageName)
		self._setPagePath() # self.pagePath
		self._setFilePath() # self.filePath
		self.load() # self.rawText, self.tags, self.ctime

	def _setPagePath(self):
		self.pagePath = utils.joinPath(self.category.categoryPath, self.pageName)

	def _setFilePath(self):
		self.filePath = os.path.join(self.category.dirPath, self.encPageName)
	def load(self):
		fp = file(self.filePath, 'rb')
		self.perms = Permission.Permission(fp.readline().strip())
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self._setMTime()

	def setRawText(self, rawText):
		self.rawText = rawText
	def setTags(self, tags):
		self.tags = tags.strip()
	def _save(self):
		fp = file(self.filePath, 'rb')
		orgTags = fp.readline().strip()
		fp.close()

		tm = TagManager(orgTags)
		tm.update(self.tags, self)

		file(self.filePath, 'wb').write('%s\n%s\n%s' % (self.perms, self.tags, self.rawText))
		self._setMTime()

	def _setMTime(self):
		self.mtime = os.path.getmtime(self.filePath)

	def edit(self, rawText, tags, writedTime=0):
		writedTime = float(writedTime)
		if writedTime and writedTime < os.path.getmtime(self.filePath):
			raise EditConflict
		self.rawText = rawText
		self.tags = tags.strip()
		self._save()
	def editPerm(self, s): 
		self.perms = Permission.Permission(s.strip())
		self._save()
	def backup(self):
		backupRepository = Repository.getBackupRepository()
		backupDir = os.path.join(backupRepository, Category.categoryPathToFilePath(self.category.categoryPath))
		if not os.path.exists(backupDir):
			os.makedirs(backupDir)
		descPath = '%s.%s' % (os.path.join(backupDir, self.encPageName), int(os.path.getmtime(self.filePath)))
		shutil.copy2(self.filePath, descPath)

	def remove(self):
		if not os.path.isfile(self.filePath):
			raise NotExistPage
		os.remove(self.filePath)
		return True

	def toLink(self, klass='', linkName=''):
		return utils.makeLink(self.category.categoryPath, self.pageName, klass=klass, linkName=linkName)


def getPage(categoryPath, pageName):
	category = Category.getCategoryByCategoryPath(categoryPath)
	if category:
		page = category.getPage(pageName)
		return page
	return None

def getPageFromDescendants(categoryPath, pageName, myFilter=None):
	category = Category.getCategoryByCategoryPath(categoryPath)
	if category:
		pageList = category.getPageListFromDescendants(myFilter)
		if pageList:
			return pageList[0]
	return None

def travelAlongRails(categoryPath, pageName):
	page = getPage(categoryPath, pageName)
	if page:
		return page
	myFilter = lambda page:page.pageName == pageName 
	page = getPageFromDescendants(categoryPath, pageName, myFilter)
	if page:
		return page
	page = getPage(config.globalCategoryName, pageName)
	if page:
		return page
	return None

==> imwiki-0.6.1.tar.gz: imwiki-0.6.1/imLib/Page.py <==
# -*- coding: utf8 -*-
import urllib
import os
import shutil
import time

import config
import utils 
from Tag import Tag
from TagManager import TagManager
import Request
import Category
import Repository
import Permission

from WikiException import WikiException
class ExistPage(WikiException): pass 
class ExistCategory(WikiException): pass 
class EditConflict(WikiException): pass
class NotExistPage(WikiException): pass

def createPage(category, pageName, rawText, tags='', perms=''):
	encPageName = utils.encode(pageName)
	filePath = os.path.join(category.dirPath, encPageName)
	if os.path.isfile(filePath):
		raise ExistPage
	if os.path.isdir(filePath):
		raise ExistCategory
	tm = TagManager(tags)
	tags = tm.getTagString()
	if not perms:
		perms = category.perms
	file(filePath, 'wb').write('%s\n%s\n%s' % (perms, tags, rawText))
	page = Page(category, pageName)
	for tag in tm.toSet():
		Tag(tag).append(page)
	return page

class Page:
	def __init__(self, category, pageName):
		self.category = category
		self.pageName = pageName
		self.encPageName = utils.encode(pageName)
		self._setPagePath() # self.pagePath
		self._setFilePath() # self.filePath
		self.load() # self.rawText, self.tags, self.ctime

	def _setPagePath(self):
		self.pagePath = utils.joinPath(self.category.categoryPath, self.pageName)

	def _setFilePath(self):
		self.filePath = os.path.join(self.category.dirPath, self.encPageName)
	def load(self):
		fp = file(self.filePath, 'rb')
		self.perms = Permission.Permission(fp.readline().strip())
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self._setMTime()

	def setRawText(self, rawText):
		self.rawText = rawText
	def setTags(self, tags):
		self.tags = tags.strip()
	def _save(self):
		fp = file(self.filePath, 'rb')
		orgTags = fp.readline().strip()
		fp.close()

		tm = TagManager(orgTags)
		tm.update(self.tags, self)

		file(self.filePath, 'wb').write('%s\n%s\n%s' % (self.perms, self.tags, self.rawText))
		self._setMTime()

	def _setMTime(self):
		self.mtime = str(os.path.getmtime(self.filePath))

	def edit(self, rawText, tags, perms='', writedTime=0):
		#writedTime = float(writedTime) # FIXME webInferface에서 검사하고있음.
		#if writedTime and writedTime < float(os.path.getmtime(self.filePath)):
		#	raise EditConflict 
		if not perms:
			perms = self.perms
		self.perms = Permission.Permission(perms)
		self.rawText = rawText
		self.tags = tags.strip()
		self._save()
	def editPerm(self, s): 
		self.perms = Permission.Permission(s.strip())
		self._save()
	def backup(self):
		backupRepository = Repository.getBackupRepository()
		backupDir = os.path.join(backupRepository, Category.categoryPathToFilePath(self.category.categoryPath))
		if not os.path.exists(backupDir):
			os.makedirs(backupDir)
		descPath = '%s.%s' % (os.path.join(backupDir, self.encPageName), int(os.path.getmtime(self.filePath)))
		shutil.copy2(self.filePath, descPath)

	def remove(self):
		if not os.path.isfile(self.filePath):
			raise NotExistPage
		os.remove(self.filePath)
		return True

	def toLink(self, klass='', linkName=''):
		return utils.makeLink(self.category.categoryPath, self.pageName, klass=klass, linkName=linkName)


def getPage(categoryPath, pageName):
	category = Category.getCategoryByCategoryPath(categoryPath)
	if category:
		page = category.getPage(pageName)
		return page
	return None

def getPageFromDescendants(categoryPath, pageName, myFilter=None):
	category = Category.getCategoryByCategoryPath(categoryPath)
	if category:
		pageList = category.getPageListFromDescendants(myFilter)
		if pageList:
			return pageList[0]
	return None

def travelAlongRails(categoryPath, pageName):
	page = getPage(categoryPath, pageName)
	if page:
		return page
	myFilter = lambda page:page.pageName == pageName 
	page = getPageFromDescendants(categoryPath, pageName, myFilter)
	if page:
		return page
	page = getPage(config.globalCategoryName, pageName)
	if page:
		return page
	return None
